"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class AppScanSaaSModelsV2IASTAnalyzer:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agentkey": "str",
        "id": "str",
        "name": "str",
        "fully_automatic": "bool",
        "created_at": "datetime",
        "last_modified": "datetime",
        "recurrence_rule": "str",
        "next_scheduled_run": "datetime",
        "recurrence_end_date": "datetime",
        "app_id": "str",
        "app_name": "str",
        "technology": "str",
        "latest_execution": "AppScanSaaSModelsV2IastAnalyzerScanExecution",
        "enable_mail_notification": "bool",
        "executions_ids": "list[str]",
        "deleted_allowed": "bool",
        "offering_triggered": "bool",
        "is_private": "bool",
        "is_personal": "bool",
        "is_completed": "bool",
        "url": "str",
        "rescan_allowed": "bool",
        "presence": "UserSiteCommonModelsPresence",
        "iast_agent_status": "str",
        "iast_agent_type": "str",
        "iast_conn_lost_stop_timer": "int",
        "offering_type": "str",
        "is_uploaded_file": "bool",
        "parsed_from_uploaded_file": "bool",
        "created_by": "UserSiteCommonModelsBasicUserInfo",
        "use_test_optimizer": "bool",
        "test_optimization_level": "str",
        "is_demo_scan": "bool",
        "expiration_time": "datetime",
    }

    attribute_map = {
        "agentkey": "Agentkey",
        "id": "Id",
        "name": "Name",
        "fully_automatic": "FullyAutomatic",
        "created_at": "CreatedAt",
        "last_modified": "LastModified",
        "recurrence_rule": "RecurrenceRule",
        "next_scheduled_run": "NextScheduledRun",
        "recurrence_end_date": "RecurrenceEndDate",
        "app_id": "AppId",
        "app_name": "AppName",
        "technology": "Technology",
        "latest_execution": "LatestExecution",
        "enable_mail_notification": "EnableMailNotification",
        "executions_ids": "ExecutionsIds",
        "deleted_allowed": "DeletedAllowed",
        "offering_triggered": "OfferingTriggered",
        "is_private": "IsPrivate",
        "is_personal": "IsPersonal",
        "is_completed": "IsCompleted",
        "url": "Url",
        "rescan_allowed": "RescanAllowed",
        "presence": "Presence",
        "iast_agent_status": "IastAgentStatus",
        "iast_agent_type": "IastAgentType",
        "iast_conn_lost_stop_timer": "IastConnLostStopTimer",
        "offering_type": "OfferingType",
        "is_uploaded_file": "IsUploadedFile",
        "parsed_from_uploaded_file": "ParsedFromUploadedFile",
        "created_by": "CreatedBy",
        "use_test_optimizer": "UseTestOptimizer",
        "test_optimization_level": "TestOptimizationLevel",
        "is_demo_scan": "IsDemoScan",
        "expiration_time": "ExpirationTime",
    }

    def __init__(
        self,
        agentkey=None,
        id=None,
        name=None,
        fully_automatic=None,
        created_at=None,
        last_modified=None,
        recurrence_rule=None,
        next_scheduled_run=None,
        recurrence_end_date=None,
        app_id=None,
        app_name=None,
        technology=None,
        latest_execution=None,
        enable_mail_notification=None,
        executions_ids=None,
        deleted_allowed=None,
        offering_triggered=None,
        is_private=None,
        is_personal=None,
        is_completed=None,
        url=None,
        rescan_allowed=None,
        presence=None,
        iast_agent_status=None,
        iast_agent_type=None,
        iast_conn_lost_stop_timer=None,
        offering_type=None,
        is_uploaded_file=None,
        parsed_from_uploaded_file=None,
        created_by=None,
        use_test_optimizer=None,
        test_optimization_level=None,
        is_demo_scan=None,
        expiration_time=None,
        _configuration=None,
    ):
        """AppScanSaaSModelsV2IASTAnalyzer - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._agentkey = None
        self._id = None
        self._name = None
        self._fully_automatic = None
        self._created_at = None
        self._last_modified = None
        self._recurrence_rule = None
        self._next_scheduled_run = None
        self._recurrence_end_date = None
        self._app_id = None
        self._app_name = None
        self._technology = None
        self._latest_execution = None
        self._enable_mail_notification = None
        self._executions_ids = None
        self._deleted_allowed = None
        self._offering_triggered = None
        self._is_private = None
        self._is_personal = None
        self._is_completed = None
        self._url = None
        self._rescan_allowed = None
        self._presence = None
        self._iast_agent_status = None
        self._iast_agent_type = None
        self._iast_conn_lost_stop_timer = None
        self._offering_type = None
        self._is_uploaded_file = None
        self._parsed_from_uploaded_file = None
        self._created_by = None
        self._use_test_optimizer = None
        self._test_optimization_level = None
        self._is_demo_scan = None
        self._expiration_time = None
        self.discriminator = None

        if agentkey is not None:
            self.agentkey = agentkey
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if fully_automatic is not None:
            self.fully_automatic = fully_automatic
        if created_at is not None:
            self.created_at = created_at
        if last_modified is not None:
            self.last_modified = last_modified
        if recurrence_rule is not None:
            self.recurrence_rule = recurrence_rule
        if next_scheduled_run is not None:
            self.next_scheduled_run = next_scheduled_run
        if recurrence_end_date is not None:
            self.recurrence_end_date = recurrence_end_date
        if app_id is not None:
            self.app_id = app_id
        if app_name is not None:
            self.app_name = app_name
        if technology is not None:
            self.technology = technology
        if latest_execution is not None:
            self.latest_execution = latest_execution
        if enable_mail_notification is not None:
            self.enable_mail_notification = enable_mail_notification
        if executions_ids is not None:
            self.executions_ids = executions_ids
        if deleted_allowed is not None:
            self.deleted_allowed = deleted_allowed
        if offering_triggered is not None:
            self.offering_triggered = offering_triggered
        if is_private is not None:
            self.is_private = is_private
        if is_personal is not None:
            self.is_personal = is_personal
        if is_completed is not None:
            self.is_completed = is_completed
        if url is not None:
            self.url = url
        if rescan_allowed is not None:
            self.rescan_allowed = rescan_allowed
        if presence is not None:
            self.presence = presence
        if iast_agent_status is not None:
            self.iast_agent_status = iast_agent_status
        if iast_agent_type is not None:
            self.iast_agent_type = iast_agent_type
        if iast_conn_lost_stop_timer is not None:
            self.iast_conn_lost_stop_timer = iast_conn_lost_stop_timer
        if offering_type is not None:
            self.offering_type = offering_type
        if is_uploaded_file is not None:
            self.is_uploaded_file = is_uploaded_file
        if parsed_from_uploaded_file is not None:
            self.parsed_from_uploaded_file = parsed_from_uploaded_file
        if created_by is not None:
            self.created_by = created_by
        if use_test_optimizer is not None:
            self.use_test_optimizer = use_test_optimizer
        if test_optimization_level is not None:
            self.test_optimization_level = test_optimization_level
        if is_demo_scan is not None:
            self.is_demo_scan = is_demo_scan
        if expiration_time is not None:
            self.expiration_time = expiration_time

    @property
    def agentkey(self):
        # type: () -> str
        """Gets the agentkey of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The agentkey of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._agentkey

    @agentkey.setter
    def agentkey(self, agentkey):
        """Sets the agentkey of this AppScanSaaSModelsV2IASTAnalyzer.


        :param agentkey: The agentkey of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """

        self._agentkey = agentkey

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The id of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AppScanSaaSModelsV2IASTAnalyzer.


        :param id: The id of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The name of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AppScanSaaSModelsV2IASTAnalyzer.


        :param name: The name of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """

        self._name = name

    @property
    def fully_automatic(self):
        # type: () -> bool
        """Gets the fully_automatic of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The fully_automatic of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._fully_automatic

    @fully_automatic.setter
    def fully_automatic(self, fully_automatic):
        """Sets the fully_automatic of this AppScanSaaSModelsV2IASTAnalyzer.


        :param fully_automatic: The fully_automatic of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._fully_automatic = fully_automatic

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The created_at of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AppScanSaaSModelsV2IASTAnalyzer.


        :param created_at: The created_at of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: datetime
        """

        self._created_at = created_at

    @property
    def last_modified(self):
        # type: () -> datetime
        """Gets the last_modified of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The last_modified of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: datetime
        """
        return self._last_modified

    @last_modified.setter
    def last_modified(self, last_modified):
        """Sets the last_modified of this AppScanSaaSModelsV2IASTAnalyzer.


        :param last_modified: The last_modified of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: datetime
        """

        self._last_modified = last_modified

    @property
    def recurrence_rule(self):
        # type: () -> str
        """Gets the recurrence_rule of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The recurrence_rule of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._recurrence_rule

    @recurrence_rule.setter
    def recurrence_rule(self, recurrence_rule):
        """Sets the recurrence_rule of this AppScanSaaSModelsV2IASTAnalyzer.


        :param recurrence_rule: The recurrence_rule of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """

        self._recurrence_rule = recurrence_rule

    @property
    def next_scheduled_run(self):
        # type: () -> datetime
        """Gets the next_scheduled_run of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The next_scheduled_run of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: datetime
        """
        return self._next_scheduled_run

    @next_scheduled_run.setter
    def next_scheduled_run(self, next_scheduled_run):
        """Sets the next_scheduled_run of this AppScanSaaSModelsV2IASTAnalyzer.


        :param next_scheduled_run: The next_scheduled_run of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: datetime
        """

        self._next_scheduled_run = next_scheduled_run

    @property
    def recurrence_end_date(self):
        # type: () -> datetime
        """Gets the recurrence_end_date of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The recurrence_end_date of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: datetime
        """
        return self._recurrence_end_date

    @recurrence_end_date.setter
    def recurrence_end_date(self, recurrence_end_date):
        """Sets the recurrence_end_date of this AppScanSaaSModelsV2IASTAnalyzer.


        :param recurrence_end_date: The recurrence_end_date of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: datetime
        """

        self._recurrence_end_date = recurrence_end_date

    @property
    def app_id(self):
        # type: () -> str
        """Gets the app_id of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The app_id of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this AppScanSaaSModelsV2IASTAnalyzer.


        :param app_id: The app_id of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """

        self._app_id = app_id

    @property
    def app_name(self):
        # type: () -> str
        """Gets the app_name of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The app_name of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this AppScanSaaSModelsV2IASTAnalyzer.


        :param app_name: The app_name of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """

        self._app_name = app_name

    @property
    def technology(self):
        # type: () -> str
        """Gets the technology of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The technology of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._technology

    @technology.setter
    def technology(self, technology):
        """Sets the technology of this AppScanSaaSModelsV2IASTAnalyzer.


        :param technology: The technology of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """
        allowed_values = [
            "DynamicAnalyzer",
            "StaticAnalyzer",
            "MobileAnalyzerAndroid",
            "MobileAnalyzerIos",
            "IFA",
            "DastAutomation",
            "IASTAnalyzer",
            "ScaAnalyzer",
        ]
        if self._configuration.client_side_validation and technology not in allowed_values:
            raise ValueError(
                "Invalid value for `technology` ({}), must be one of {}".format(
                    technology, allowed_values
                )
            )

        self._technology = technology

    @property
    def latest_execution(self):
        # type: () -> AppScanSaaSModelsV2IastAnalyzerScanExecution
        """Gets the latest_execution of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The latest_execution of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: AppScanSaaSModelsV2IastAnalyzerScanExecution
        """
        return self._latest_execution

    @latest_execution.setter
    def latest_execution(self, latest_execution):
        """Sets the latest_execution of this AppScanSaaSModelsV2IASTAnalyzer.


        :param latest_execution: The latest_execution of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: AppScanSaaSModelsV2IastAnalyzerScanExecution
        """

        self._latest_execution = latest_execution

    @property
    def enable_mail_notification(self):
        # type: () -> bool
        """Gets the enable_mail_notification of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The enable_mail_notification of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._enable_mail_notification

    @enable_mail_notification.setter
    def enable_mail_notification(self, enable_mail_notification):
        """Sets the enable_mail_notification of this AppScanSaaSModelsV2IASTAnalyzer.


        :param enable_mail_notification: The enable_mail_notification of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._enable_mail_notification = enable_mail_notification

    @property
    def executions_ids(self):
        # type: () -> list[str]
        """Gets the executions_ids of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The executions_ids of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: list[str]
        """
        return self._executions_ids

    @executions_ids.setter
    def executions_ids(self, executions_ids):
        """Sets the executions_ids of this AppScanSaaSModelsV2IASTAnalyzer.


        :param executions_ids: The executions_ids of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: list[str]
        """

        self._executions_ids = executions_ids

    @property
    def deleted_allowed(self):
        # type: () -> bool
        """Gets the deleted_allowed of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The deleted_allowed of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._deleted_allowed

    @deleted_allowed.setter
    def deleted_allowed(self, deleted_allowed):
        """Sets the deleted_allowed of this AppScanSaaSModelsV2IASTAnalyzer.


        :param deleted_allowed: The deleted_allowed of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._deleted_allowed = deleted_allowed

    @property
    def offering_triggered(self):
        # type: () -> bool
        """Gets the offering_triggered of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The offering_triggered of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._offering_triggered

    @offering_triggered.setter
    def offering_triggered(self, offering_triggered):
        """Sets the offering_triggered of this AppScanSaaSModelsV2IASTAnalyzer.


        :param offering_triggered: The offering_triggered of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._offering_triggered = offering_triggered

    @property
    def is_private(self):
        # type: () -> bool
        """Gets the is_private of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The is_private of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._is_private

    @is_private.setter
    def is_private(self, is_private):
        """Sets the is_private of this AppScanSaaSModelsV2IASTAnalyzer.


        :param is_private: The is_private of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._is_private = is_private

    @property
    def is_personal(self):
        # type: () -> bool
        """Gets the is_personal of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The is_personal of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._is_personal

    @is_personal.setter
    def is_personal(self, is_personal):
        """Sets the is_personal of this AppScanSaaSModelsV2IASTAnalyzer.


        :param is_personal: The is_personal of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._is_personal = is_personal

    @property
    def is_completed(self):
        # type: () -> bool
        """Gets the is_completed of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The is_completed of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._is_completed

    @is_completed.setter
    def is_completed(self, is_completed):
        """Sets the is_completed of this AppScanSaaSModelsV2IASTAnalyzer.


        :param is_completed: The is_completed of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._is_completed = is_completed

    @property
    def url(self):
        # type: () -> str
        """Gets the url of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The url of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AppScanSaaSModelsV2IASTAnalyzer.


        :param url: The url of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """

        self._url = url

    @property
    def rescan_allowed(self):
        # type: () -> bool
        """Gets the rescan_allowed of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The rescan_allowed of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._rescan_allowed

    @rescan_allowed.setter
    def rescan_allowed(self, rescan_allowed):
        """Sets the rescan_allowed of this AppScanSaaSModelsV2IASTAnalyzer.


        :param rescan_allowed: The rescan_allowed of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._rescan_allowed = rescan_allowed

    @property
    def presence(self):
        # type: () -> UserSiteCommonModelsPresence
        """Gets the presence of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The presence of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: UserSiteCommonModelsPresence
        """
        return self._presence

    @presence.setter
    def presence(self, presence):
        """Sets the presence of this AppScanSaaSModelsV2IASTAnalyzer.


        :param presence: The presence of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: UserSiteCommonModelsPresence
        """

        self._presence = presence

    @property
    def iast_agent_status(self):
        # type: () -> str
        """Gets the iast_agent_status of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The iast_agent_status of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._iast_agent_status

    @iast_agent_status.setter
    def iast_agent_status(self, iast_agent_status):
        """Sets the iast_agent_status of this AppScanSaaSModelsV2IASTAnalyzer.


        :param iast_agent_status: The iast_agent_status of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """
        allowed_values = ["None", "Active", "KeyNeverUsed", "Inactive"]
        if self._configuration.client_side_validation and iast_agent_status not in allowed_values:
            raise ValueError(
                "Invalid value for `iast_agent_status` ({}), must be one of {}".format(
                    iast_agent_status, allowed_values
                )
            )

        self._iast_agent_status = iast_agent_status

    @property
    def iast_agent_type(self):
        # type: () -> str
        """Gets the iast_agent_type of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The iast_agent_type of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._iast_agent_type

    @iast_agent_type.setter
    def iast_agent_type(self, iast_agent_type):
        """Sets the iast_agent_type of this AppScanSaaSModelsV2IASTAnalyzer.


        :param iast_agent_type: The iast_agent_type of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """
        allowed_values = ["Java", "DotNet", "NodeJS"]
        if self._configuration.client_side_validation and iast_agent_type not in allowed_values:
            raise ValueError(
                "Invalid value for `iast_agent_type` ({}), must be one of {}".format(
                    iast_agent_type, allowed_values
                )
            )

        self._iast_agent_type = iast_agent_type

    @property
    def iast_conn_lost_stop_timer(self):
        # type: () -> int
        """Gets the iast_conn_lost_stop_timer of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The iast_conn_lost_stop_timer of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: int
        """
        return self._iast_conn_lost_stop_timer

    @iast_conn_lost_stop_timer.setter
    def iast_conn_lost_stop_timer(self, iast_conn_lost_stop_timer):
        """Sets the iast_conn_lost_stop_timer of this AppScanSaaSModelsV2IASTAnalyzer.


        :param iast_conn_lost_stop_timer: The iast_conn_lost_stop_timer of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: int
        """

        self._iast_conn_lost_stop_timer = iast_conn_lost_stop_timer

    @property
    def offering_type(self):
        # type: () -> str
        """Gets the offering_type of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The offering_type of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._offering_type

    @offering_type.setter
    def offering_type(self, offering_type):
        """Sets the offering_type of this AppScanSaaSModelsV2IASTAnalyzer.


        :param offering_type: The offering_type of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """
        allowed_values = [
            "None",
            "Trial",
            "HTrial",
            "Applications",
            "ScanExecution",
            "AnalyzerConcurrent",
            "ConsultantServices",
            "Premium",
            "OpenSourcePerApplication",
            "OpenSourcePremium",
            "OpenSourceConcurrent",
            "IASTConcurrent",
            "IASTPayPerApp",
            "Promotional",
            "Silver",
            "Gold",
            "Platinum",
            "SCAPerApplication",
        ]
        if self._configuration.client_side_validation and offering_type not in allowed_values:
            raise ValueError(
                "Invalid value for `offering_type` ({}), must be one of {}".format(
                    offering_type, allowed_values
                )
            )

        self._offering_type = offering_type

    @property
    def is_uploaded_file(self):
        # type: () -> bool
        """Gets the is_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The is_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._is_uploaded_file

    @is_uploaded_file.setter
    def is_uploaded_file(self, is_uploaded_file):
        """Sets the is_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.


        :param is_uploaded_file: The is_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._is_uploaded_file = is_uploaded_file

    @property
    def parsed_from_uploaded_file(self):
        # type: () -> bool
        """Gets the parsed_from_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The parsed_from_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._parsed_from_uploaded_file

    @parsed_from_uploaded_file.setter
    def parsed_from_uploaded_file(self, parsed_from_uploaded_file):
        """Sets the parsed_from_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.


        :param parsed_from_uploaded_file: The parsed_from_uploaded_file of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._parsed_from_uploaded_file = parsed_from_uploaded_file

    @property
    def created_by(self):
        # type: () -> UserSiteCommonModelsBasicUserInfo
        """Gets the created_by of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The created_by of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: UserSiteCommonModelsBasicUserInfo
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this AppScanSaaSModelsV2IASTAnalyzer.


        :param created_by: The created_by of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: UserSiteCommonModelsBasicUserInfo
        """

        self._created_by = created_by

    @property
    def use_test_optimizer(self):
        # type: () -> bool
        """Gets the use_test_optimizer of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The use_test_optimizer of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._use_test_optimizer

    @use_test_optimizer.setter
    def use_test_optimizer(self, use_test_optimizer):
        """Sets the use_test_optimizer of this AppScanSaaSModelsV2IASTAnalyzer.


        :param use_test_optimizer: The use_test_optimizer of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._use_test_optimizer = use_test_optimizer

    @property
    def test_optimization_level(self):
        # type: () -> str
        """Gets the test_optimization_level of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The test_optimization_level of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: str
        """
        return self._test_optimization_level

    @test_optimization_level.setter
    def test_optimization_level(self, test_optimization_level):
        """Sets the test_optimization_level of this AppScanSaaSModelsV2IASTAnalyzer.


        :param test_optimization_level: The test_optimization_level of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: str
        """
        allowed_values = ["NoOptimization", "Fast", "Faster", "Fastest"]
        if (
            self._configuration.client_side_validation
            and test_optimization_level not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `test_optimization_level` ({}), must be one of {}".format(
                    test_optimization_level, allowed_values
                )
            )

        self._test_optimization_level = test_optimization_level

    @property
    def is_demo_scan(self):
        # type: () -> bool
        """Gets the is_demo_scan of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The is_demo_scan of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: bool
        """
        return self._is_demo_scan

    @is_demo_scan.setter
    def is_demo_scan(self, is_demo_scan):
        """Sets the is_demo_scan of this AppScanSaaSModelsV2IASTAnalyzer.


        :param is_demo_scan: The is_demo_scan of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: bool
        """

        self._is_demo_scan = is_demo_scan

    @property
    def expiration_time(self):
        # type: () -> datetime
        """Gets the expiration_time of this AppScanSaaSModelsV2IASTAnalyzer.


        :return: The expiration_time of this AppScanSaaSModelsV2IASTAnalyzer.
        :rtype: datetime
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """Sets the expiration_time of this AppScanSaaSModelsV2IASTAnalyzer.


        :param expiration_time: The expiration_time of this AppScanSaaSModelsV2IASTAnalyzer.
        :type: datetime
        """

        self._expiration_time = expiration_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AppScanSaaSModelsV2IASTAnalyzer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppScanSaaSModelsV2IASTAnalyzer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppScanSaaSModelsV2IASTAnalyzer):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UtilitiesStructuresTenantInfoModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "tenant_name": "str",
        "contact_email": "str",
        "subscription_technologies": "str",
        "auto_delete_exceeded_scans_per_app": "bool",
        "allow_app_manager_override_auto_delete_settings": "bool",
    }

    attribute_map = {
        "tenant_name": "TenantName",
        "contact_email": "ContactEmail",
        "subscription_technologies": "SubscriptionTechnologies",
        "auto_delete_exceeded_scans_per_app": "AutoDeleteExceededScansPerApp",
        "allow_app_manager_override_auto_delete_settings": "AllowAppManagerOverrideAutoDeleteSettings",
    }

    def __init__(
        self,
        tenant_name=None,
        contact_email=None,
        subscription_technologies=None,
        auto_delete_exceeded_scans_per_app=None,
        allow_app_manager_override_auto_delete_settings=None,
        _configuration=None,
    ):
        """UtilitiesStructuresTenantInfoModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._tenant_name = None
        self._contact_email = None
        self._subscription_technologies = None
        self._auto_delete_exceeded_scans_per_app = None
        self._allow_app_manager_override_auto_delete_settings = None
        self.discriminator = None

        if tenant_name is not None:
            self.tenant_name = tenant_name
        if contact_email is not None:
            self.contact_email = contact_email
        if subscription_technologies is not None:
            self.subscription_technologies = subscription_technologies
        if auto_delete_exceeded_scans_per_app is not None:
            self.auto_delete_exceeded_scans_per_app = auto_delete_exceeded_scans_per_app
        if allow_app_manager_override_auto_delete_settings is not None:
            self.allow_app_manager_override_auto_delete_settings = (
                allow_app_manager_override_auto_delete_settings
            )

    @property
    def tenant_name(self):
        # type: () -> str
        """Gets the tenant_name of this UtilitiesStructuresTenantInfoModel.


        :return: The tenant_name of this UtilitiesStructuresTenantInfoModel.
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this UtilitiesStructuresTenantInfoModel.


        :param tenant_name: The tenant_name of this UtilitiesStructuresTenantInfoModel.
        :type: str
        """

        self._tenant_name = tenant_name

    @property
    def contact_email(self):
        # type: () -> str
        """Gets the contact_email of this UtilitiesStructuresTenantInfoModel.


        :return: The contact_email of this UtilitiesStructuresTenantInfoModel.
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """Sets the contact_email of this UtilitiesStructuresTenantInfoModel.


        :param contact_email: The contact_email of this UtilitiesStructuresTenantInfoModel.
        :type: str
        """

        self._contact_email = contact_email

    @property
    def subscription_technologies(self):
        # type: () -> str
        """Gets the subscription_technologies of this UtilitiesStructuresTenantInfoModel.


        :return: The subscription_technologies of this UtilitiesStructuresTenantInfoModel.
        :rtype: str
        """
        return self._subscription_technologies

    @subscription_technologies.setter
    def subscription_technologies(self, subscription_technologies):
        """Sets the subscription_technologies of this UtilitiesStructuresTenantInfoModel.


        :param subscription_technologies: The subscription_technologies of this UtilitiesStructuresTenantInfoModel.
        :type: str
        """
        allowed_values = [
            "DynamicAnalyzer",
            "StaticAnalyzer",
            "IASTAnalyzer",
            "SCAAnalyzer",
        ]
        if (
            self._configuration.client_side_validation
            and subscription_technologies not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `subscription_technologies` ({}), must be one of {}".format(
                    subscription_technologies, allowed_values
                )
            )

        self._subscription_technologies = subscription_technologies

    @property
    def auto_delete_exceeded_scans_per_app(self):
        # type: () -> bool
        """Gets the auto_delete_exceeded_scans_per_app of this UtilitiesStructuresTenantInfoModel.


        :return: The auto_delete_exceeded_scans_per_app of this UtilitiesStructuresTenantInfoModel.
        :rtype: bool
        """
        return self._auto_delete_exceeded_scans_per_app

    @auto_delete_exceeded_scans_per_app.setter
    def auto_delete_exceeded_scans_per_app(self, auto_delete_exceeded_scans_per_app):
        """Sets the auto_delete_exceeded_scans_per_app of this UtilitiesStructuresTenantInfoModel.


        :param auto_delete_exceeded_scans_per_app: The auto_delete_exceeded_scans_per_app of this UtilitiesStructuresTenantInfoModel.
        :type: bool
        """

        self._auto_delete_exceeded_scans_per_app = auto_delete_exceeded_scans_per_app

    @property
    def allow_app_manager_override_auto_delete_settings(self):
        # type: () -> bool
        """Gets the allow_app_manager_override_auto_delete_settings of this UtilitiesStructuresTenantInfoModel.


        :return: The allow_app_manager_override_auto_delete_settings of this UtilitiesStructuresTenantInfoModel.
        :rtype: bool
        """
        return self._allow_app_manager_override_auto_delete_settings

    @allow_app_manager_override_auto_delete_settings.setter
    def allow_app_manager_override_auto_delete_settings(
        self, allow_app_manager_override_auto_delete_settings
    ):
        """Sets the allow_app_manager_override_auto_delete_settings of this UtilitiesStructuresTenantInfoModel.


        :param allow_app_manager_override_auto_delete_settings: The allow_app_manager_override_auto_delete_settings of this UtilitiesStructuresTenantInfoModel.
        :type: bool
        """

        self._allow_app_manager_override_auto_delete_settings = (
            allow_app_manager_override_auto_delete_settings
        )

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UtilitiesStructuresTenantInfoModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UtilitiesStructuresTenantInfoModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UtilitiesStructuresTenantInfoModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsSecurityReportJob:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "configuration": "UtilitiesStructuresSecurityReportOptions",
        "odata_filter": "str",
        "apply_policies": "str",
        "select_policy_ids": "list[str]",
    }

    attribute_map = {
        "configuration": "Configuration",
        "odata_filter": "OdataFilter",
        "apply_policies": "ApplyPolicies",
        "select_policy_ids": "SelectPolicyIds",
    }

    def __init__(
        self,
        configuration=None,
        odata_filter=None,
        apply_policies=None,
        select_policy_ids=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsSecurityReportJob - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._configuration = None
        self._odata_filter = None
        self._apply_policies = None
        self._select_policy_ids = None
        self.discriminator = None

        self.configuration = configuration
        if odata_filter is not None:
            self.odata_filter = odata_filter
        if apply_policies is not None:
            self.apply_policies = apply_policies
        if select_policy_ids is not None:
            self.select_policy_ids = select_policy_ids

    @property
    def configuration(self):
        # type: () -> UtilitiesStructuresSecurityReportOptions
        """Gets the configuration of this UserSiteCommonModelsSecurityReportJob.


        :return: The configuration of this UserSiteCommonModelsSecurityReportJob.
        :rtype: UtilitiesStructuresSecurityReportOptions
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this UserSiteCommonModelsSecurityReportJob.


        :param configuration: The configuration of this UserSiteCommonModelsSecurityReportJob.
        :type: UtilitiesStructuresSecurityReportOptions
        """
        if self._configuration.client_side_validation and configuration is None:
            raise ValueError("Invalid value for `configuration`, must not be `None`")

        self._configuration = configuration

    @property
    def odata_filter(self):
        # type: () -> str
        """Gets the odata_filter of this UserSiteCommonModelsSecurityReportJob.


        :return: The odata_filter of this UserSiteCommonModelsSecurityReportJob.
        :rtype: str
        """
        return self._odata_filter

    @odata_filter.setter
    def odata_filter(self, odata_filter):
        """Sets the odata_filter of this UserSiteCommonModelsSecurityReportJob.


        :param odata_filter: The odata_filter of this UserSiteCommonModelsSecurityReportJob.
        :type: str
        """

        self._odata_filter = odata_filter

    @property
    def apply_policies(self):
        # type: () -> str
        """Gets the apply_policies of this UserSiteCommonModelsSecurityReportJob.


        :return: The apply_policies of this UserSiteCommonModelsSecurityReportJob.
        :rtype: str
        """
        return self._apply_policies

    @apply_policies.setter
    def apply_policies(self, apply_policies):
        """Sets the apply_policies of this UserSiteCommonModelsSecurityReportJob.


        :param apply_policies: The apply_policies of this UserSiteCommonModelsSecurityReportJob.
        :type: str
        """
        allowed_values = ["None", "All", "Select"]
        if self._configuration.client_side_validation and apply_policies not in allowed_values:
            raise ValueError(
                "Invalid value for `apply_policies` ({}), must be one of {}".format(
                    apply_policies, allowed_values
                )
            )

        self._apply_policies = apply_policies

    @property
    def select_policy_ids(self):
        # type: () -> list[str]
        """Gets the select_policy_ids of this UserSiteCommonModelsSecurityReportJob.


        :return: The select_policy_ids of this UserSiteCommonModelsSecurityReportJob.
        :rtype: list[str]
        """
        return self._select_policy_ids

    @select_policy_ids.setter
    def select_policy_ids(self, select_policy_ids):
        """Sets the select_policy_ids of this UserSiteCommonModelsSecurityReportJob.


        :param select_policy_ids: The select_policy_ids of this UserSiteCommonModelsSecurityReportJob.
        :type: list[str]
        """

        self._select_policy_ids = select_policy_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsSecurityReportJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsSecurityReportJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsSecurityReportJob):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class AppScanSaaSModelsV2IssueChangeSet:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "scan_execution": "AppScanSaaSModelsV2ScanExecutionInfo",
        "changes": "list[AppScanSaaSModelsV2Change]",
        "changed_at": "datetime",
        "changed_by": "UserSiteCommonModelsBasicUserInfo",
    }

    attribute_map = {
        "scan_execution": "ScanExecution",
        "changes": "Changes",
        "changed_at": "ChangedAt",
        "changed_by": "ChangedBy",
    }

    def __init__(
        self,
        scan_execution=None,
        changes=None,
        changed_at=None,
        changed_by=None,
        _configuration=None,
    ):
        """AppScanSaaSModelsV2IssueChangeSet - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._scan_execution = None
        self._changes = None
        self._changed_at = None
        self._changed_by = None
        self.discriminator = None

        if scan_execution is not None:
            self.scan_execution = scan_execution
        if changes is not None:
            self.changes = changes
        if changed_at is not None:
            self.changed_at = changed_at
        if changed_by is not None:
            self.changed_by = changed_by

    @property
    def scan_execution(self):
        # type: () -> AppScanSaaSModelsV2ScanExecutionInfo
        """Gets the scan_execution of this AppScanSaaSModelsV2IssueChangeSet.


        :return: The scan_execution of this AppScanSaaSModelsV2IssueChangeSet.
        :rtype: AppScanSaaSModelsV2ScanExecutionInfo
        """
        return self._scan_execution

    @scan_execution.setter
    def scan_execution(self, scan_execution):
        """Sets the scan_execution of this AppScanSaaSModelsV2IssueChangeSet.


        :param scan_execution: The scan_execution of this AppScanSaaSModelsV2IssueChangeSet.
        :type: AppScanSaaSModelsV2ScanExecutionInfo
        """

        self._scan_execution = scan_execution

    @property
    def changes(self):
        # type: () -> list[AppScanSaaSModelsV2Change]
        """Gets the changes of this AppScanSaaSModelsV2IssueChangeSet.


        :return: The changes of this AppScanSaaSModelsV2IssueChangeSet.
        :rtype: list[AppScanSaaSModelsV2Change]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """Sets the changes of this AppScanSaaSModelsV2IssueChangeSet.


        :param changes: The changes of this AppScanSaaSModelsV2IssueChangeSet.
        :type: list[AppScanSaaSModelsV2Change]
        """

        self._changes = changes

    @property
    def changed_at(self):
        # type: () -> datetime
        """Gets the changed_at of this AppScanSaaSModelsV2IssueChangeSet.


        :return: The changed_at of this AppScanSaaSModelsV2IssueChangeSet.
        :rtype: datetime
        """
        return self._changed_at

    @changed_at.setter
    def changed_at(self, changed_at):
        """Sets the changed_at of this AppScanSaaSModelsV2IssueChangeSet.


        :param changed_at: The changed_at of this AppScanSaaSModelsV2IssueChangeSet.
        :type: datetime
        """

        self._changed_at = changed_at

    @property
    def changed_by(self):
        # type: () -> UserSiteCommonModelsBasicUserInfo
        """Gets the changed_by of this AppScanSaaSModelsV2IssueChangeSet.


        :return: The changed_by of this AppScanSaaSModelsV2IssueChangeSet.
        :rtype: UserSiteCommonModelsBasicUserInfo
        """
        return self._changed_by

    @changed_by.setter
    def changed_by(self, changed_by):
        """Sets the changed_by of this AppScanSaaSModelsV2IssueChangeSet.


        :param changed_by: The changed_by of this AppScanSaaSModelsV2IssueChangeSet.
        :type: UserSiteCommonModelsBasicUserInfo
        """

        self._changed_by = changed_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AppScanSaaSModelsV2IssueChangeSet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppScanSaaSModelsV2IssueChangeSet):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppScanSaaSModelsV2IssueChangeSet):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class CommonModelsSCXAccountTenantInfo:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "number_of_apps": "int",
        "tenant_id": "str",
        "tenant_name": "str",
        "contact_email": "str",
        "subscriptions": "list[CommonModelsSCXAccountSCXSubscription]",
        "hide_usage_counters": "bool",
        "issues_status_inheritance": "str",
        "subscription_technologies": "str",
        "active_technologies": "str",
        "user_info": "CommonModelsSCXAccountSCXUserInfo",
        "entitled_for_expert_on_demand": "bool",
        "num_business_units_in_org": "int",
        "apps_with_business_unit": "int",
        "apps_without_business_unit": "int",
        "sca_enabled": "bool",
        "max_scans_per_app": "int",
        "auto_delete_exceeded_scans_per_app": "bool",
        "allow_app_manager_override_auto_delete_settings": "bool",
    }

    attribute_map = {
        "number_of_apps": "NumberOfApps",
        "tenant_id": "TenantId",
        "tenant_name": "TenantName",
        "contact_email": "ContactEmail",
        "subscriptions": "Subscriptions",
        "hide_usage_counters": "HideUsageCounters",
        "issues_status_inheritance": "IssuesStatusInheritance",
        "subscription_technologies": "SubscriptionTechnologies",
        "active_technologies": "ActiveTechnologies",
        "user_info": "UserInfo",
        "entitled_for_expert_on_demand": "EntitledForExpertOnDemand",
        "num_business_units_in_org": "NumBusinessUnitsInOrg",
        "apps_with_business_unit": "AppsWithBusinessUnit",
        "apps_without_business_unit": "AppsWithoutBusinessUnit",
        "sca_enabled": "SCAEnabled",
        "max_scans_per_app": "MaxScansPerApp",
        "auto_delete_exceeded_scans_per_app": "AutoDeleteExceededScansPerApp",
        "allow_app_manager_override_auto_delete_settings": "AllowAppManagerOverrideAutoDeleteSettings",
    }

    def __init__(
        self,
        number_of_apps=None,
        tenant_id=None,
        tenant_name=None,
        contact_email=None,
        subscriptions=None,
        hide_usage_counters=None,
        issues_status_inheritance=None,
        subscription_technologies=None,
        active_technologies=None,
        user_info=None,
        entitled_for_expert_on_demand=None,
        num_business_units_in_org=None,
        apps_with_business_unit=None,
        apps_without_business_unit=None,
        sca_enabled=None,
        max_scans_per_app=None,
        auto_delete_exceeded_scans_per_app=None,
        allow_app_manager_override_auto_delete_settings=None,
        _configuration=None,
    ):
        """CommonModelsSCXAccountTenantInfo - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._number_of_apps = None
        self._tenant_id = None
        self._tenant_name = None
        self._contact_email = None
        self._subscriptions = None
        self._hide_usage_counters = None
        self._issues_status_inheritance = None
        self._subscription_technologies = None
        self._active_technologies = None
        self._user_info = None
        self._entitled_for_expert_on_demand = None
        self._num_business_units_in_org = None
        self._apps_with_business_unit = None
        self._apps_without_business_unit = None
        self._sca_enabled = None
        self._max_scans_per_app = None
        self._auto_delete_exceeded_scans_per_app = None
        self._allow_app_manager_override_auto_delete_settings = None
        self.discriminator = None

        if number_of_apps is not None:
            self.number_of_apps = number_of_apps
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if tenant_name is not None:
            self.tenant_name = tenant_name
        if contact_email is not None:
            self.contact_email = contact_email
        if subscriptions is not None:
            self.subscriptions = subscriptions
        if hide_usage_counters is not None:
            self.hide_usage_counters = hide_usage_counters
        if issues_status_inheritance is not None:
            self.issues_status_inheritance = issues_status_inheritance
        if subscription_technologies is not None:
            self.subscription_technologies = subscription_technologies
        if active_technologies is not None:
            self.active_technologies = active_technologies
        if user_info is not None:
            self.user_info = user_info
        if entitled_for_expert_on_demand is not None:
            self.entitled_for_expert_on_demand = entitled_for_expert_on_demand
        if num_business_units_in_org is not None:
            self.num_business_units_in_org = num_business_units_in_org
        if apps_with_business_unit is not None:
            self.apps_with_business_unit = apps_with_business_unit
        if apps_without_business_unit is not None:
            self.apps_without_business_unit = apps_without_business_unit
        if sca_enabled is not None:
            self.sca_enabled = sca_enabled
        if max_scans_per_app is not None:
            self.max_scans_per_app = max_scans_per_app
        if auto_delete_exceeded_scans_per_app is not None:
            self.auto_delete_exceeded_scans_per_app = auto_delete_exceeded_scans_per_app
        if allow_app_manager_override_auto_delete_settings is not None:
            self.allow_app_manager_override_auto_delete_settings = (
                allow_app_manager_override_auto_delete_settings
            )

    @property
    def number_of_apps(self):
        # type: () -> int
        """Gets the number_of_apps of this CommonModelsSCXAccountTenantInfo.


        :return: The number_of_apps of this CommonModelsSCXAccountTenantInfo.
        :rtype: int
        """
        return self._number_of_apps

    @number_of_apps.setter
    def number_of_apps(self, number_of_apps):
        """Sets the number_of_apps of this CommonModelsSCXAccountTenantInfo.


        :param number_of_apps: The number_of_apps of this CommonModelsSCXAccountTenantInfo.
        :type: int
        """

        self._number_of_apps = number_of_apps

    @property
    def tenant_id(self):
        # type: () -> str
        """Gets the tenant_id of this CommonModelsSCXAccountTenantInfo.


        :return: The tenant_id of this CommonModelsSCXAccountTenantInfo.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this CommonModelsSCXAccountTenantInfo.


        :param tenant_id: The tenant_id of this CommonModelsSCXAccountTenantInfo.
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def tenant_name(self):
        # type: () -> str
        """Gets the tenant_name of this CommonModelsSCXAccountTenantInfo.


        :return: The tenant_name of this CommonModelsSCXAccountTenantInfo.
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this CommonModelsSCXAccountTenantInfo.


        :param tenant_name: The tenant_name of this CommonModelsSCXAccountTenantInfo.
        :type: str
        """

        self._tenant_name = tenant_name

    @property
    def contact_email(self):
        # type: () -> str
        """Gets the contact_email of this CommonModelsSCXAccountTenantInfo.


        :return: The contact_email of this CommonModelsSCXAccountTenantInfo.
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """Sets the contact_email of this CommonModelsSCXAccountTenantInfo.


        :param contact_email: The contact_email of this CommonModelsSCXAccountTenantInfo.
        :type: str
        """

        self._contact_email = contact_email

    @property
    def subscriptions(self):
        # type: () -> list[CommonModelsSCXAccountSCXSubscription]
        """Gets the subscriptions of this CommonModelsSCXAccountTenantInfo.


        :return: The subscriptions of this CommonModelsSCXAccountTenantInfo.
        :rtype: list[CommonModelsSCXAccountSCXSubscription]
        """
        return self._subscriptions

    @subscriptions.setter
    def subscriptions(self, subscriptions):
        """Sets the subscriptions of this CommonModelsSCXAccountTenantInfo.


        :param subscriptions: The subscriptions of this CommonModelsSCXAccountTenantInfo.
        :type: list[CommonModelsSCXAccountSCXSubscription]
        """

        self._subscriptions = subscriptions

    @property
    def hide_usage_counters(self):
        # type: () -> bool
        """Gets the hide_usage_counters of this CommonModelsSCXAccountTenantInfo.


        :return: The hide_usage_counters of this CommonModelsSCXAccountTenantInfo.
        :rtype: bool
        """
        return self._hide_usage_counters

    @hide_usage_counters.setter
    def hide_usage_counters(self, hide_usage_counters):
        """Sets the hide_usage_counters of this CommonModelsSCXAccountTenantInfo.


        :param hide_usage_counters: The hide_usage_counters of this CommonModelsSCXAccountTenantInfo.
        :type: bool
        """

        self._hide_usage_counters = hide_usage_counters

    @property
    def issues_status_inheritance(self):
        # type: () -> str
        """Gets the issues_status_inheritance of this CommonModelsSCXAccountTenantInfo.


        :return: The issues_status_inheritance of this CommonModelsSCXAccountTenantInfo.
        :rtype: str
        """
        return self._issues_status_inheritance

    @issues_status_inheritance.setter
    def issues_status_inheritance(self, issues_status_inheritance):
        """Sets the issues_status_inheritance of this CommonModelsSCXAccountTenantInfo.


        :param issues_status_inheritance: The issues_status_inheritance of this CommonModelsSCXAccountTenantInfo.
        :type: str
        """
        allowed_values = ["None", "Noise", "Fixed"]
        if (
            self._configuration.client_side_validation
            and issues_status_inheritance not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `issues_status_inheritance` ({}), must be one of {}".format(
                    issues_status_inheritance, allowed_values
                )
            )

        self._issues_status_inheritance = issues_status_inheritance

    @property
    def subscription_technologies(self):
        # type: () -> str
        """Gets the subscription_technologies of this CommonModelsSCXAccountTenantInfo.


        :return: The subscription_technologies of this CommonModelsSCXAccountTenantInfo.
        :rtype: str
        """
        return self._subscription_technologies

    @subscription_technologies.setter
    def subscription_technologies(self, subscription_technologies):
        """Sets the subscription_technologies of this CommonModelsSCXAccountTenantInfo.


        :param subscription_technologies: The subscription_technologies of this CommonModelsSCXAccountTenantInfo.
        :type: str
        """
        allowed_values = [
            "DynamicAnalyzer",
            "StaticAnalyzer",
            "IASTAnalyzer",
            "SCAAnalyzer",
        ]
        if (
            self._configuration.client_side_validation
            and subscription_technologies not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `subscription_technologies` ({}), must be one of {}".format(
                    subscription_technologies, allowed_values
                )
            )

        self._subscription_technologies = subscription_technologies

    @property
    def active_technologies(self):
        # type: () -> str
        """Gets the active_technologies of this CommonModelsSCXAccountTenantInfo.


        :return: The active_technologies of this CommonModelsSCXAccountTenantInfo.
        :rtype: str
        """
        return self._active_technologies

    @active_technologies.setter
    def active_technologies(self, active_technologies):
        """Sets the active_technologies of this CommonModelsSCXAccountTenantInfo.


        :param active_technologies: The active_technologies of this CommonModelsSCXAccountTenantInfo.
        :type: str
        """
        allowed_values = [
            "DynamicAnalyzer",
            "StaticAnalyzer",
            "IASTAnalyzer",
            "SCAAnalyzer",
        ]
        if self._configuration.client_side_validation and active_technologies not in allowed_values:
            raise ValueError(
                "Invalid value for `active_technologies` ({}), must be one of {}".format(
                    active_technologies, allowed_values
                )
            )

        self._active_technologies = active_technologies

    @property
    def user_info(self):
        # type: () -> CommonModelsSCXAccountSCXUserInfo
        """Gets the user_info of this CommonModelsSCXAccountTenantInfo.


        :return: The user_info of this CommonModelsSCXAccountTenantInfo.
        :rtype: CommonModelsSCXAccountSCXUserInfo
        """
        return self._user_info

    @user_info.setter
    def user_info(self, user_info):
        """Sets the user_info of this CommonModelsSCXAccountTenantInfo.


        :param user_info: The user_info of this CommonModelsSCXAccountTenantInfo.
        :type: CommonModelsSCXAccountSCXUserInfo
        """

        self._user_info = user_info

    @property
    def entitled_for_expert_on_demand(self):
        # type: () -> bool
        """Gets the entitled_for_expert_on_demand of this CommonModelsSCXAccountTenantInfo.


        :return: The entitled_for_expert_on_demand of this CommonModelsSCXAccountTenantInfo.
        :rtype: bool
        """
        return self._entitled_for_expert_on_demand

    @entitled_for_expert_on_demand.setter
    def entitled_for_expert_on_demand(self, entitled_for_expert_on_demand):
        """Sets the entitled_for_expert_on_demand of this CommonModelsSCXAccountTenantInfo.


        :param entitled_for_expert_on_demand: The entitled_for_expert_on_demand of this CommonModelsSCXAccountTenantInfo.
        :type: bool
        """

        self._entitled_for_expert_on_demand = entitled_for_expert_on_demand

    @property
    def num_business_units_in_org(self):
        # type: () -> int
        """Gets the num_business_units_in_org of this CommonModelsSCXAccountTenantInfo.


        :return: The num_business_units_in_org of this CommonModelsSCXAccountTenantInfo.
        :rtype: int
        """
        return self._num_business_units_in_org

    @num_business_units_in_org.setter
    def num_business_units_in_org(self, num_business_units_in_org):
        """Sets the num_business_units_in_org of this CommonModelsSCXAccountTenantInfo.


        :param num_business_units_in_org: The num_business_units_in_org of this CommonModelsSCXAccountTenantInfo.
        :type: int
        """

        self._num_business_units_in_org = num_business_units_in_org

    @property
    def apps_with_business_unit(self):
        # type: () -> int
        """Gets the apps_with_business_unit of this CommonModelsSCXAccountTenantInfo.


        :return: The apps_with_business_unit of this CommonModelsSCXAccountTenantInfo.
        :rtype: int
        """
        return self._apps_with_business_unit

    @apps_with_business_unit.setter
    def apps_with_business_unit(self, apps_with_business_unit):
        """Sets the apps_with_business_unit of this CommonModelsSCXAccountTenantInfo.


        :param apps_with_business_unit: The apps_with_business_unit of this CommonModelsSCXAccountTenantInfo.
        :type: int
        """

        self._apps_with_business_unit = apps_with_business_unit

    @property
    def apps_without_business_unit(self):
        # type: () -> int
        """Gets the apps_without_business_unit of this CommonModelsSCXAccountTenantInfo.


        :return: The apps_without_business_unit of this CommonModelsSCXAccountTenantInfo.
        :rtype: int
        """
        return self._apps_without_business_unit

    @apps_without_business_unit.setter
    def apps_without_business_unit(self, apps_without_business_unit):
        """Sets the apps_without_business_unit of this CommonModelsSCXAccountTenantInfo.


        :param apps_without_business_unit: The apps_without_business_unit of this CommonModelsSCXAccountTenantInfo.
        :type: int
        """

        self._apps_without_business_unit = apps_without_business_unit

    @property
    def sca_enabled(self):
        # type: () -> bool
        """Gets the sca_enabled of this CommonModelsSCXAccountTenantInfo.


        :return: The sca_enabled of this CommonModelsSCXAccountTenantInfo.
        :rtype: bool
        """
        return self._sca_enabled

    @sca_enabled.setter
    def sca_enabled(self, sca_enabled):
        """Sets the sca_enabled of this CommonModelsSCXAccountTenantInfo.


        :param sca_enabled: The sca_enabled of this CommonModelsSCXAccountTenantInfo.
        :type: bool
        """

        self._sca_enabled = sca_enabled

    @property
    def max_scans_per_app(self):
        # type: () -> int
        """Gets the max_scans_per_app of this CommonModelsSCXAccountTenantInfo.


        :return: The max_scans_per_app of this CommonModelsSCXAccountTenantInfo.
        :rtype: int
        """
        return self._max_scans_per_app

    @max_scans_per_app.setter
    def max_scans_per_app(self, max_scans_per_app):
        """Sets the max_scans_per_app of this CommonModelsSCXAccountTenantInfo.


        :param max_scans_per_app: The max_scans_per_app of this CommonModelsSCXAccountTenantInfo.
        :type: int
        """

        self._max_scans_per_app = max_scans_per_app

    @property
    def auto_delete_exceeded_scans_per_app(self):
        # type: () -> bool
        """Gets the auto_delete_exceeded_scans_per_app of this CommonModelsSCXAccountTenantInfo.


        :return: The auto_delete_exceeded_scans_per_app of this CommonModelsSCXAccountTenantInfo.
        :rtype: bool
        """
        return self._auto_delete_exceeded_scans_per_app

    @auto_delete_exceeded_scans_per_app.setter
    def auto_delete_exceeded_scans_per_app(self, auto_delete_exceeded_scans_per_app):
        """Sets the auto_delete_exceeded_scans_per_app of this CommonModelsSCXAccountTenantInfo.


        :param auto_delete_exceeded_scans_per_app: The auto_delete_exceeded_scans_per_app of this CommonModelsSCXAccountTenantInfo.
        :type: bool
        """

        self._auto_delete_exceeded_scans_per_app = auto_delete_exceeded_scans_per_app

    @property
    def allow_app_manager_override_auto_delete_settings(self):
        # type: () -> bool
        """Gets the allow_app_manager_override_auto_delete_settings of this CommonModelsSCXAccountTenantInfo.


        :return: The allow_app_manager_override_auto_delete_settings of this CommonModelsSCXAccountTenantInfo.
        :rtype: bool
        """
        return self._allow_app_manager_override_auto_delete_settings

    @allow_app_manager_override_auto_delete_settings.setter
    def allow_app_manager_override_auto_delete_settings(
        self, allow_app_manager_override_auto_delete_settings
    ):
        """Sets the allow_app_manager_override_auto_delete_settings of this CommonModelsSCXAccountTenantInfo.


        :param allow_app_manager_override_auto_delete_settings: The allow_app_manager_override_auto_delete_settings of this CommonModelsSCXAccountTenantInfo.
        :type: bool
        """

        self._allow_app_manager_override_auto_delete_settings = (
            allow_app_manager_override_auto_delete_settings
        )

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CommonModelsSCXAccountTenantInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommonModelsSCXAccountTenantInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CommonModelsSCXAccountTenantInfo):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsAssetGroupModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "description": "str",
        "is_default": "bool",
        "contact_person": "UserSiteCommonModelsBasicUserInfo",
        "apps_count": "int",
        "users_count": "int",
        "issues_status_inheritance": "str",
    }

    attribute_map = {
        "id": "Id",
        "name": "Name",
        "description": "Description",
        "is_default": "IsDefault",
        "contact_person": "ContactPerson",
        "apps_count": "AppsCount",
        "users_count": "UsersCount",
        "issues_status_inheritance": "IssuesStatusInheritance",
    }

    def __init__(
        self,
        id=None,
        name=None,
        description=None,
        is_default=None,
        contact_person=None,
        apps_count=None,
        users_count=None,
        issues_status_inheritance=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsAssetGroupModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._is_default = None
        self._contact_person = None
        self._apps_count = None
        self._users_count = None
        self._issues_status_inheritance = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if is_default is not None:
            self.is_default = is_default
        if contact_person is not None:
            self.contact_person = contact_person
        if apps_count is not None:
            self.apps_count = apps_count
        if users_count is not None:
            self.users_count = users_count
        if issues_status_inheritance is not None:
            self.issues_status_inheritance = issues_status_inheritance

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UserSiteCommonModelsAssetGroupModel.


        :return: The id of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserSiteCommonModelsAssetGroupModel.


        :param id: The id of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this UserSiteCommonModelsAssetGroupModel.


        :return: The name of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserSiteCommonModelsAssetGroupModel.


        :param name: The name of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """
        if self._configuration.client_side_validation and name is not None and len(name) > 120:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `120`")
        if self._configuration.client_side_validation and name is not None and len(name) < 0:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `0`"
            )

        self._name = name

    @property
    def description(self):
        # type: () -> str
        """Gets the description of this UserSiteCommonModelsAssetGroupModel.


        :return: The description of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UserSiteCommonModelsAssetGroupModel.


        :param description: The description of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """

        self._description = description

    @property
    def is_default(self):
        # type: () -> bool
        """Gets the is_default of this UserSiteCommonModelsAssetGroupModel.


        :return: The is_default of this UserSiteCommonModelsAssetGroupModel.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this UserSiteCommonModelsAssetGroupModel.


        :param is_default: The is_default of this UserSiteCommonModelsAssetGroupModel.
        :type: bool
        """

        self._is_default = is_default

    @property
    def contact_person(self):
        # type: () -> UserSiteCommonModelsBasicUserInfo
        """Gets the contact_person of this UserSiteCommonModelsAssetGroupModel.


        :return: The contact_person of this UserSiteCommonModelsAssetGroupModel.
        :rtype: UserSiteCommonModelsBasicUserInfo
        """
        return self._contact_person

    @contact_person.setter
    def contact_person(self, contact_person):
        """Sets the contact_person of this UserSiteCommonModelsAssetGroupModel.


        :param contact_person: The contact_person of this UserSiteCommonModelsAssetGroupModel.
        :type: UserSiteCommonModelsBasicUserInfo
        """

        self._contact_person = contact_person

    @property
    def apps_count(self):
        # type: () -> int
        """Gets the apps_count of this UserSiteCommonModelsAssetGroupModel.


        :return: The apps_count of this UserSiteCommonModelsAssetGroupModel.
        :rtype: int
        """
        return self._apps_count

    @apps_count.setter
    def apps_count(self, apps_count):
        """Sets the apps_count of this UserSiteCommonModelsAssetGroupModel.


        :param apps_count: The apps_count of this UserSiteCommonModelsAssetGroupModel.
        :type: int
        """

        self._apps_count = apps_count

    @property
    def users_count(self):
        # type: () -> int
        """Gets the users_count of this UserSiteCommonModelsAssetGroupModel.


        :return: The users_count of this UserSiteCommonModelsAssetGroupModel.
        :rtype: int
        """
        return self._users_count

    @users_count.setter
    def users_count(self, users_count):
        """Sets the users_count of this UserSiteCommonModelsAssetGroupModel.


        :param users_count: The users_count of this UserSiteCommonModelsAssetGroupModel.
        :type: int
        """

        self._users_count = users_count

    @property
    def issues_status_inheritance(self):
        # type: () -> str
        """Gets the issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.


        :return: The issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.
        :rtype: str
        """
        return self._issues_status_inheritance

    @issues_status_inheritance.setter
    def issues_status_inheritance(self, issues_status_inheritance):
        """Sets the issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.


        :param issues_status_inheritance: The issues_status_inheritance of this UserSiteCommonModelsAssetGroupModel.
        :type: str
        """
        allowed_values = ["None", "Noise", "Fixed"]
        if (
            self._configuration.client_side_validation
            and issues_status_inheritance not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `issues_status_inheritance` ({}), must be one of {}".format(
                    issues_status_inheritance, allowed_values
                )
            )

        self._issues_status_inheritance = issues_status_inheritance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsAssetGroupModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsAssetGroupModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsAssetGroupModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import re  # noqa: F401

# python 2 and python 3 compatibility library
from pyasoc.api_client import ApiClient


class FixGroupsApi:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid(
        self, scope, scope_id, fix_group_id, **kwargs
    ):
        """Get fix group

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid(scope, scope_id, fix_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str fix_group_id: Fix Group ID (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :return: UserSiteCommonModelsFixGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(
                scope, scope_id, fix_group_id, **kwargs
            )
        else:
            (
                data
            ) = self.fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(
                scope, scope_id, fix_group_id, **kwargs
            )
            return data

    def fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(
        self, scope, scope_id, fix_group_id, **kwargs
    ):
        """Get fix group

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(scope, scope_id, fix_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str fix_group_id: Fix Group ID (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :return: UserSiteCommonModelsFixGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "scope",
            "scope_id",
            "fix_group_id",
            "apply_policies",
            "select_policy_ids",
            "locale",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid`"
            )
        # verify the required parameter 'fix_group_id' is set
        if self.api_client.client_side_validation and (
            "fix_group_id" not in params or params["fix_group_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `fix_group_id` when calling `fix_groups_get_fix_group_by_scope_and_scopeid_and_fixgroupid`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]
        if "fix_group_id" in params:
            path_params["fixGroupId"] = params["fix_group_id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"
        if "locale" in params:
            query_params.append(("locale", params["locale"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/FixGroups/{scope}/{scopeId}/{fixGroupId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsFixGroup",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def fix_groups_get_fix_groups_by_scope_and_scopeid(self, scope, scope_id, **kwargs):
        """Get fix groups in scope

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_get_fix_groups_by_scope_and_scopeid(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUserSiteCommonModelsFixGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.fix_groups_get_fix_groups_by_scope_and_scopeid_with_http_info(
                scope, scope_id, **kwargs
            )
        else:
            (data) = self.fix_groups_get_fix_groups_by_scope_and_scopeid_with_http_info(
                scope, scope_id, **kwargs
            )
            return data

    def fix_groups_get_fix_groups_by_scope_and_scopeid_with_http_info(
        self, scope, scope_id, **kwargs
    ):
        """Get fix groups in scope

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_get_fix_groups_by_scope_and_scopeid_with_http_info(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUserSiteCommonModelsFixGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "scope",
            "scope_id",
            "apply_policies",
            "select_policy_ids",
            "locale",
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
            "inlinecount",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fix_groups_get_fix_groups_by_scope_and_scopeid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `fix_groups_get_fix_groups_by_scope_and_scopeid`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `fix_groups_get_fix_groups_by_scope_and_scopeid`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"
        if "locale" in params:
            query_params.append(("locale", params["locale"]))
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))
        if "inlinecount" in params:
            query_params.append(("$inlinecount", params["inlinecount"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/FixGroups/{scope}/{scopeId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SystemWebHttpODataPageResultUserSiteCommonModelsFixGroup",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def fix_groups_get_issues_by_fix_group_id(self, scope, scope_id, fix_group_id, **kwargs):
        """Get filtered issues for a FixGroup

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_get_issues_by_fix_group_id(scope, scope_id, fix_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str fix_group_id: FixGroup ID (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUtilitiesIssueModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.fix_groups_get_issues_by_fix_group_id_with_http_info(
                scope, scope_id, fix_group_id, **kwargs
            )
        else:
            (data) = self.fix_groups_get_issues_by_fix_group_id_with_http_info(
                scope, scope_id, fix_group_id, **kwargs
            )
            return data

    def fix_groups_get_issues_by_fix_group_id_with_http_info(
        self, scope, scope_id, fix_group_id, **kwargs
    ):
        """Get filtered issues for a FixGroup

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_get_issues_by_fix_group_id_with_http_info(scope, scope_id, fix_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str fix_group_id: FixGroup ID (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUtilitiesIssueModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "scope",
            "scope_id",
            "fix_group_id",
            "apply_policies",
            "select_policy_ids",
            "locale",
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
            "inlinecount",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fix_groups_get_issues_by_fix_group_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `fix_groups_get_issues_by_fix_group_id`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `fix_groups_get_issues_by_fix_group_id`"
            )
        # verify the required parameter 'fix_group_id' is set
        if self.api_client.client_side_validation and (
            "fix_group_id" not in params or params["fix_group_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `fix_group_id` when calling `fix_groups_get_issues_by_fix_group_id`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]
        if "fix_group_id" in params:
            path_params["fixGroupId"] = params["fix_group_id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"
        if "locale" in params:
            query_params.append(("locale", params["locale"]))
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))
        if "inlinecount" in params:
            query_params.append(("$inlinecount", params["inlinecount"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/FixGroups/{scope}/{scopeId}/{fixGroupId}/Issues",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SystemWebHttpODataPageResultUtilitiesIssueModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid(
        self, scope, scope_id, fix_group_id, fix_group_model, **kwargs
    ):
        """Update a fix group according to a given scope

        The StickyStatus parameter determines how the new Status affects issues in the FixGroup.<br />  If StickyStatus is False, the Status you set affects only issues in the FixGroup that are filtered-in by the scope and policy.<br />  If StickyStatus is True, the Status is applied to all issues in the FixGroup (scope and policy are ignored), including new issues  that become associated with it later.<br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid(scope, scope_id, fix_group_id, fix_group_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str fix_group_id: Fix Group ID (required)
        :param UserSiteCommonModelsFixGroupUpdate fix_group_model:  (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: UserSiteCommonModelsTriageResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return (
                self.fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(
                    scope, scope_id, fix_group_id, fix_group_model, **kwargs
                )
            )
        else:
            (
                data
            ) = self.fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(
                scope, scope_id, fix_group_id, fix_group_model, **kwargs
            )
            return data

    def fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(
        self, scope, scope_id, fix_group_id, fix_group_model, **kwargs
    ):
        """Update a fix group according to a given scope

        The StickyStatus parameter determines how the new Status affects issues in the FixGroup.<br />  If StickyStatus is False, the Status you set affects only issues in the FixGroup that are filtered-in by the scope and policy.<br />  If StickyStatus is True, the Status is applied to all issues in the FixGroup (scope and policy are ignored), including new issues  that become associated with it later.<br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid_with_http_info(scope, scope_id, fix_group_id, fix_group_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the fix group (required)
        :param str scope_id: id of the Scope (required)
        :param str fix_group_id: Fix Group ID (required)
        :param UserSiteCommonModelsFixGroupUpdate fix_group_model:  (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: UserSiteCommonModelsTriageResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "scope",
            "scope_id",
            "fix_group_id",
            "fix_group_model",
            "apply_policies",
            "select_policy_ids",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid"
                    % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid`"
            )
        # verify the required parameter 'fix_group_id' is set
        if self.api_client.client_side_validation and (
            "fix_group_id" not in params or params["fix_group_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `fix_group_id` when calling `fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid`"
            )
        # verify the required parameter 'fix_group_model' is set
        if self.api_client.client_side_validation and (
            "fix_group_model" not in params or params["fix_group_model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `fix_group_model` when calling `fix_groups_update_fix_group_by_scope_and_scopeid_and_fixgroupid`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]
        if "fix_group_id" in params:
            path_params["fixGroupId"] = params["fix_group_id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "fix_group_model" in params:
            body_params = params["fix_group_model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/FixGroups/{scope}/{scopeId}/{fixGroupId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsTriageResult",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UtilitiesStructuresSecurityReportOptions:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "summary": "bool",
        "details": "bool",
        "discussion": "bool",
        "overview": "bool",
        "table_of_content": "bool",
        "advisories": "bool",
        "fix_recommendation": "bool",
        "history": "bool",
        "coverage": "bool",
        "minimize_details": "bool",
        "articles": "bool",
        "report_file_type": "str",
        "title": "str",
        "notes": "str",
        "locale": "str",
    }

    attribute_map = {
        "summary": "Summary",
        "details": "Details",
        "discussion": "Discussion",
        "overview": "Overview",
        "table_of_content": "TableOfContent",
        "advisories": "Advisories",
        "fix_recommendation": "FixRecommendation",
        "history": "History",
        "coverage": "Coverage",
        "minimize_details": "MinimizeDetails",
        "articles": "Articles",
        "report_file_type": "ReportFileType",
        "title": "Title",
        "notes": "Notes",
        "locale": "Locale",
    }

    def __init__(
        self,
        summary=None,
        details=None,
        discussion=None,
        overview=None,
        table_of_content=None,
        advisories=None,
        fix_recommendation=None,
        history=None,
        coverage=None,
        minimize_details=None,
        articles=None,
        report_file_type=None,
        title=None,
        notes=None,
        locale=None,
        _configuration=None,
    ):
        """UtilitiesStructuresSecurityReportOptions - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._summary = None
        self._details = None
        self._discussion = None
        self._overview = None
        self._table_of_content = None
        self._advisories = None
        self._fix_recommendation = None
        self._history = None
        self._coverage = None
        self._minimize_details = None
        self._articles = None
        self._report_file_type = None
        self._title = None
        self._notes = None
        self._locale = None
        self.discriminator = None

        if summary is not None:
            self.summary = summary
        if details is not None:
            self.details = details
        if discussion is not None:
            self.discussion = discussion
        if overview is not None:
            self.overview = overview
        if table_of_content is not None:
            self.table_of_content = table_of_content
        if advisories is not None:
            self.advisories = advisories
        if fix_recommendation is not None:
            self.fix_recommendation = fix_recommendation
        if history is not None:
            self.history = history
        if coverage is not None:
            self.coverage = coverage
        if minimize_details is not None:
            self.minimize_details = minimize_details
        if articles is not None:
            self.articles = articles
        if report_file_type is not None:
            self.report_file_type = report_file_type
        if title is not None:
            self.title = title
        if notes is not None:
            self.notes = notes
        if locale is not None:
            self.locale = locale

    @property
    def summary(self):
        # type: () -> bool
        """Gets the summary of this UtilitiesStructuresSecurityReportOptions.


        :return: The summary of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this UtilitiesStructuresSecurityReportOptions.


        :param summary: The summary of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._summary = summary

    @property
    def details(self):
        # type: () -> bool
        """Gets the details of this UtilitiesStructuresSecurityReportOptions.


        :return: The details of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this UtilitiesStructuresSecurityReportOptions.


        :param details: The details of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._details = details

    @property
    def discussion(self):
        # type: () -> bool
        """Gets the discussion of this UtilitiesStructuresSecurityReportOptions.


        :return: The discussion of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._discussion

    @discussion.setter
    def discussion(self, discussion):
        """Sets the discussion of this UtilitiesStructuresSecurityReportOptions.


        :param discussion: The discussion of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._discussion = discussion

    @property
    def overview(self):
        # type: () -> bool
        """Gets the overview of this UtilitiesStructuresSecurityReportOptions.


        :return: The overview of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._overview

    @overview.setter
    def overview(self, overview):
        """Sets the overview of this UtilitiesStructuresSecurityReportOptions.


        :param overview: The overview of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._overview = overview

    @property
    def table_of_content(self):
        # type: () -> bool
        """Gets the table_of_content of this UtilitiesStructuresSecurityReportOptions.


        :return: The table_of_content of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._table_of_content

    @table_of_content.setter
    def table_of_content(self, table_of_content):
        """Sets the table_of_content of this UtilitiesStructuresSecurityReportOptions.


        :param table_of_content: The table_of_content of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._table_of_content = table_of_content

    @property
    def advisories(self):
        # type: () -> bool
        """Gets the advisories of this UtilitiesStructuresSecurityReportOptions.


        :return: The advisories of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._advisories

    @advisories.setter
    def advisories(self, advisories):
        """Sets the advisories of this UtilitiesStructuresSecurityReportOptions.


        :param advisories: The advisories of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._advisories = advisories

    @property
    def fix_recommendation(self):
        # type: () -> bool
        """Gets the fix_recommendation of this UtilitiesStructuresSecurityReportOptions.


        :return: The fix_recommendation of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._fix_recommendation

    @fix_recommendation.setter
    def fix_recommendation(self, fix_recommendation):
        """Sets the fix_recommendation of this UtilitiesStructuresSecurityReportOptions.


        :param fix_recommendation: The fix_recommendation of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._fix_recommendation = fix_recommendation

    @property
    def history(self):
        # type: () -> bool
        """Gets the history of this UtilitiesStructuresSecurityReportOptions.


        :return: The history of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._history

    @history.setter
    def history(self, history):
        """Sets the history of this UtilitiesStructuresSecurityReportOptions.


        :param history: The history of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._history = history

    @property
    def coverage(self):
        # type: () -> bool
        """Gets the coverage of this UtilitiesStructuresSecurityReportOptions.


        :return: The coverage of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._coverage

    @coverage.setter
    def coverage(self, coverage):
        """Sets the coverage of this UtilitiesStructuresSecurityReportOptions.


        :param coverage: The coverage of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._coverage = coverage

    @property
    def minimize_details(self):
        # type: () -> bool
        """Gets the minimize_details of this UtilitiesStructuresSecurityReportOptions.


        :return: The minimize_details of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._minimize_details

    @minimize_details.setter
    def minimize_details(self, minimize_details):
        """Sets the minimize_details of this UtilitiesStructuresSecurityReportOptions.


        :param minimize_details: The minimize_details of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._minimize_details = minimize_details

    @property
    def articles(self):
        # type: () -> bool
        """Gets the articles of this UtilitiesStructuresSecurityReportOptions.


        :return: The articles of this UtilitiesStructuresSecurityReportOptions.
        :rtype: bool
        """
        return self._articles

    @articles.setter
    def articles(self, articles):
        """Sets the articles of this UtilitiesStructuresSecurityReportOptions.


        :param articles: The articles of this UtilitiesStructuresSecurityReportOptions.
        :type: bool
        """

        self._articles = articles

    @property
    def report_file_type(self):
        # type: () -> str
        """Gets the report_file_type of this UtilitiesStructuresSecurityReportOptions.


        :return: The report_file_type of this UtilitiesStructuresSecurityReportOptions.
        :rtype: str
        """
        return self._report_file_type

    @report_file_type.setter
    def report_file_type(self, report_file_type):
        """Sets the report_file_type of this UtilitiesStructuresSecurityReportOptions.


        :param report_file_type: The report_file_type of this UtilitiesStructuresSecurityReportOptions.
        :type: str
        """
        allowed_values = ["Pdf", "Html", "Xml", "Csv", "Sarif"]
        if self._configuration.client_side_validation and report_file_type not in allowed_values:
            raise ValueError(
                "Invalid value for `report_file_type` ({}), must be one of {}".format(
                    report_file_type, allowed_values
                )
            )

        self._report_file_type = report_file_type

    @property
    def title(self):
        # type: () -> str
        """Gets the title of this UtilitiesStructuresSecurityReportOptions.


        :return: The title of this UtilitiesStructuresSecurityReportOptions.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this UtilitiesStructuresSecurityReportOptions.


        :param title: The title of this UtilitiesStructuresSecurityReportOptions.
        :type: str
        """

        self._title = title

    @property
    def notes(self):
        # type: () -> str
        """Gets the notes of this UtilitiesStructuresSecurityReportOptions.


        :return: The notes of this UtilitiesStructuresSecurityReportOptions.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this UtilitiesStructuresSecurityReportOptions.


        :param notes: The notes of this UtilitiesStructuresSecurityReportOptions.
        :type: str
        """

        self._notes = notes

    @property
    def locale(self):
        # type: () -> str
        """Gets the locale of this UtilitiesStructuresSecurityReportOptions.


        :return: The locale of this UtilitiesStructuresSecurityReportOptions.
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this UtilitiesStructuresSecurityReportOptions.


        :param locale: The locale of this UtilitiesStructuresSecurityReportOptions.
        :type: str
        """

        self._locale = locale

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UtilitiesStructuresSecurityReportOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UtilitiesStructuresSecurityReportOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UtilitiesStructuresSecurityReportOptions):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import re  # noqa: F401

# python 2 and python 3 compatibility library
from pyasoc.api_client import ApiClient
from pyasoc.models.user_site_common_models_api_key import UserSiteCommonModelsApiKey


class AccountApi:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def account_api_key_login(self, api_key: UserSiteCommonModelsApiKey, **kwargs):
        """Users login with API Key

        Used only if you have an active subscription to the service.<br />               Login using this action is allowed only for a user associated with a valid service subscription.<br />               This action returns an access token that can be used as \"Bearer Token\" for accessing the API.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_api_key_login(api_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsApiKey api_key: API Key (required)
        :return: UserSiteCommonModelsAccessTokenData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.account_api_key_login_with_http_info(api_key, **kwargs)
        else:
            (data) = self.account_api_key_login_with_http_info(api_key, **kwargs)
            return data

    def account_api_key_login_with_http_info(self, api_key, **kwargs):
        """Users login with API Key

        Used only if you have an active subscription to the service.<br />               Login using this action is allowed only for a user associated with a valid service subscription.<br />               This action returns an access token that can be used as \"Bearer Token\" for accessing the API.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_api_key_login_with_http_info(api_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsApiKey api_key: API Key (required)
        :return: UserSiteCommonModelsAccessTokenData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["api_key"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_api_key_login" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'api_key' is set
        if self.api_client.client_side_validation and (
            "api_key" not in params or params["api_key"] is None
        ):
            raise ValueError(
                "Missing the required parameter `api_key` when calling `account_api_key_login`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "api_key" in params:
            body_params = params["api_key"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            "/api/V2/Account/ApiKeyLogin",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsAccessTokenData",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def account_get_tenant_info(self, **kwargs):
        """Get information about the Tenant

        Return information about the current user and the Tenant (Organization). Including information about the available subscriptions.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_get_tenant_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CommonModelsSCXAccountTenantInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.account_get_tenant_info_with_http_info(**kwargs)
        else:
            (data) = self.account_get_tenant_info_with_http_info(**kwargs)
            return data

    def account_get_tenant_info_with_http_info(self, **kwargs):
        """Get information about the Tenant

        Return information about the current user and the Tenant (Organization). Including information about the available subscriptions.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_get_tenant_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CommonModelsSCXAccountTenantInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_get_tenant_info" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Account/TenantInfo",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CommonModelsSCXAccountTenantInfo",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def account_invite(self, invite_model, **kwargs):
        """Invite User to the current organization

        This function is obsolete. Please use POST /api/v2/Account/InviteUsers
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_invite(invite_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsInviteModel invite_model:  (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.account_invite_with_http_info(invite_model, **kwargs)
        else:
            (data) = self.account_invite_with_http_info(invite_model, **kwargs)
            return data

    def account_invite_with_http_info(self, invite_model, **kwargs):
        """Invite User to the current organization

        This function is obsolete. Please use POST /api/v2/Account/InviteUsers
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_invite_with_http_info(invite_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsInviteModel invite_model:  (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["invite_model"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method account_invite" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'invite_model' is set
        if self.api_client.client_side_validation and (
            "invite_model" not in params or params["invite_model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `invite_model` when calling `account_invite`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "invite_model" in params:
            body_params = params["invite_model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Account/Invite",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def account_invite_users(self, invite_model, **kwargs):
        """Invite User to the current organization

        Up to 100 users per call. <br />              Connect users with up to 10 AssetGroups
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_invite_users(invite_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsInviteUsersModel invite_model:  (required)
        :return: list[UserSiteCommonModelsInviteResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.account_invite_users_with_http_info(invite_model, **kwargs)
        else:
            (data) = self.account_invite_users_with_http_info(invite_model, **kwargs)
            return data

    def account_invite_users_with_http_info(self, invite_model, **kwargs):
        """Invite User to the current organization

        Up to 100 users per call. <br />              Connect users with up to 10 AssetGroups
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_invite_users_with_http_info(invite_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsInviteUsersModel invite_model:  (required)
        :return: list[UserSiteCommonModelsInviteResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["invite_model"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_invite_users" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'invite_model' is set
        if self.api_client.client_side_validation and (
            "invite_model" not in params or params["invite_model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `invite_model` when calling `account_invite_users`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "invite_model" in params:
            body_params = params["invite_model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Account/InviteUsers",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[UserSiteCommonModelsInviteResult]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def account_logout(self, **kwargs):
        """Logout - revoke the access token

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_logout(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.account_logout_with_http_info(**kwargs)
        else:
            (data) = self.account_logout_with_http_info(**kwargs)
            return data

    def account_logout_with_http_info(self, **kwargs):
        """Logout - revoke the access token

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_logout_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method account_logout" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Account/Logout",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def account_subscription_info(self, **kwargs):
        """Get information about the subscription

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_subscription_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserSiteCommonModelsSubscriptionInfoModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.account_subscription_info_with_http_info(**kwargs)
        else:
            (data) = self.account_subscription_info_with_http_info(**kwargs)
            return data

    def account_subscription_info_with_http_info(self, **kwargs):
        """Get information about the subscription

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_subscription_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserSiteCommonModelsSubscriptionInfoModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_subscription_info" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Account/SubscriptionInfo",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsSubscriptionInfoModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def account_update_tenant_info(self, model, **kwargs):
        """Update tenant info

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_update_tenant_info(model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UtilitiesStructuresTenantInfoModel model: (required)
        :return: UtilitiesStructuresTenantInfoModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.account_update_tenant_info_with_http_info(model, **kwargs)
        else:
            (data) = self.account_update_tenant_info_with_http_info(model, **kwargs)
            return data

    def account_update_tenant_info_with_http_info(self, model, **kwargs):
        """Update tenant info

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.account_update_tenant_info_with_http_info(model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UtilitiesStructuresTenantInfoModel model: (required)
        :return: UtilitiesStructuresTenantInfoModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["model"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_update_tenant_info" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'model' is set
        if self.api_client.client_side_validation and (
            "model" not in params or params["model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `model` when calling `account_update_tenant_info`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "model" in params:
            body_params = params["model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Account/TenantInfo",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UtilitiesStructuresTenantInfoModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""
__version__: str = "0.3.1"

# import apis into sdk package

# import ApiClient

# import models into sdk package
